@@ -1,5 +1,4 @@
 from os.path import basename, dirname, exists, isdir, isfile, join, realpath, split
-import importlib
 import glob
 from shutil import rmtree
 from six import PY2, with_metaclass
@@ -21,22 +20,27 @@ from pythonforandroid.logger import (logger, info, warning, debug, shprint, info
 from pythonforandroid.util import (urlretrieve, current_directory, ensure_dir,
                                    BuildInterruptingException)
 
-# this import is necessary to keep imp.load_source from complaining :)
-if PY2:
-    import imp
-    import_recipe = imp.load_source
-else:
-    import importlib.util
-    if hasattr(importlib.util, 'module_from_spec'):
-        def import_recipe(module, filename):
+
+def import_recipe(module, filename):
+    if PY2:
+        import imp
+        import warnings
+        with warnings.catch_warnings():
+            # ignores warnings raised by hierarchical module names
+            # (names containing dots) on Python 2
+            warnings.simplefilter("ignore", RuntimeWarning)
+            return imp.load_source(module, filename)
+    else:
+        # Python 3.5+
+        import importlib.util
+        if hasattr(importlib.util, 'module_from_spec'):
             spec = importlib.util.spec_from_file_location(module, filename)
             mod = importlib.util.module_from_spec(spec)
             spec.loader.exec_module(mod)
             return mod
-    else:
-        from importlib.machinery import SourceFileLoader
-
-        def import_recipe(module, filename):
+        else:
+            # Python 3.3 and 3.4:
+            from importlib.machinery import SourceFileLoader
             return SourceFileLoader(module, filename).load_module()
 
 
@@ -140,8 +144,9 @@ class Recipe(with_metaclass(RecipeMeta)):
                 else:
                     progression = '{0:.2f}%'.format(
                         index * blksize * 100. / float(size))
-                stdout.write('- Download {}\r'.format(progression))
-                stdout.flush()
+                if "CI" not in environ:
+                    stdout.write('- Download {}\r'.format(progression))
+                    stdout.flush()
 
             if exists(target):
                 unlink(target)
@@ -574,6 +579,7 @@ class Recipe(with_metaclass(RecipeMeta)):
     @classmethod
     def get_recipe(cls, name, ctx):
         '''Returns the Recipe with the given name, if it exists.'''
+        name = name.lower()
         if not hasattr(cls, "recipes"):
             cls.recipes = {}
         if name in cls.recipes:
@@ -581,20 +587,28 @@ class Recipe(with_metaclass(RecipeMeta)):
 
         recipe_file = None
         for recipes_dir in cls.recipe_dirs(ctx):
-            recipe_file = join(recipes_dir, name, '__init__.py')
-            if exists(recipe_file):
+            if not exists(recipes_dir):
+                continue
+            # Find matching folder (may differ in case):
+            for subfolder in listdir(recipes_dir):
+                if subfolder.lower() == name:
+                    recipe_file = join(recipes_dir, subfolder, '__init__.py')
+                    if exists(recipe_file):
+                        name = subfolder  # adapt to actual spelling
+                        break
+                    recipe_file = None
+            if recipe_file is not None:
                 break
-            recipe_file = None
 
         if not recipe_file:
-            raise IOError('Recipe does not exist: {}'.format(name))
+            raise ValueError('Recipe does not exist: {}'.format(name))
 
         mod = import_recipe('pythonforandroid.recipes.{}'.format(name), recipe_file)
         if len(logger.handlers) > 1:
             logger.removeHandler(logger.handlers[1])
         recipe = mod.recipe
         recipe.ctx = ctx
-        cls.recipes[name] = recipe
+        cls.recipes[name.lower()] = recipe
         return recipe
 
 
@@ -716,7 +730,7 @@ class PythonRecipe(Recipe):
     def __init__(self, *args, **kwargs):
         super(PythonRecipe, self).__init__(*args, **kwargs)
         depends = self.depends
-        depends.append(('python2', 'python2legacy', 'python3', 'python3crystax'))
+        depends.append(('python2', 'python3', 'python3crystax'))
         depends = list(set(depends))
         self.depends = depends
 
@@ -739,7 +753,7 @@ class PythonRecipe(Recipe):
         host_build = Recipe.get_recipe(host_name, self.ctx).get_build_dir()
         if host_name in ['hostpython2', 'hostpython3']:
             return join(host_build, 'native-build', 'python')
-        elif host_name in ['hostpython3crystax', 'hostpython2legacy']:
+        elif host_name in ['hostpython3crystax']:
             return join(host_build, 'hostpython')
         else:
             python_recipe = self.ctx.python_recipe
@@ -781,10 +795,6 @@ class PythonRecipe(Recipe):
                     self.ctx.python_recipe.major_minor_version_string)
                 if python_name == 'python3':
                     env['LDFLAGS'] += 'm'
-                elif python_name == 'python2legacy':
-                    env['PYTHON_ROOT'] = join(
-                        self.ctx.python_recipe.get_build_dir(
-                            arch.arch), 'python-install')
             else:
                 ndk_dir_python = join(self.ctx.ndk_dir, 'sources',
                                       'python', python_version)
@@ -836,27 +846,11 @@ class PythonRecipe(Recipe):
 
         with current_directory(self.get_build_dir(arch.arch)):
             hostpython = sh.Command(self.hostpython_location)
-
-            if self.ctx.python_recipe.name != 'python2legacy':
-                hpenv = env.copy()
-                shprint(hostpython, 'setup.py', 'install', '-O2',
-                        '--root={}'.format(self.ctx.get_python_install_dir()),
-                        '--install-lib=.',
-                        _env=hpenv, *self.setup_extra_args)
-            elif self.call_hostpython_via_targetpython:
-                shprint(hostpython, 'setup.py', 'install', '-O2', _env=env,
-                        *self.setup_extra_args)
-            else:  # python2legacy
-                hppath = join(dirname(self.hostpython_location), 'Lib', 'site-packages')
-                hpenv = env.copy()
-                if 'PYTHONPATH' in hpenv:
-                    hpenv['PYTHONPATH'] = ':'.join([hppath] + hpenv['PYTHONPATH'].split(':'))
-                else:
-                    hpenv['PYTHONPATH'] = hppath
-                shprint(hostpython, 'setup.py', 'install', '-O2',
-                        '--root={}'.format(self.ctx.get_python_install_dir()),
-                        '--install-lib=lib/python2.7/site-packages',
-                        _env=hpenv, *self.setup_extra_args)
+            hpenv = env.copy()
+            shprint(hostpython, 'setup.py', 'install', '-O2',
+                    '--root={}'.format(self.ctx.get_python_install_dir()),
+                    '--install-lib=.',
+                    _env=hpenv, *self.setup_extra_args)
 
             # If asked, also install in the hostpython build dir
             if self.install_in_hostpython:
@@ -960,7 +954,7 @@ class CythonRecipe(PythonRecipe):
     def __init__(self, *args, **kwargs):
         super(CythonRecipe, self).__init__(*args, **kwargs)
         depends = self.depends
-        depends.append(('python2', 'python2legacy', 'python3', 'python3crystax'))
+        depends.append(('python2', 'python3', 'python3crystax'))
         depends = list(set(depends))
         self.depends = depends
 
@@ -980,7 +974,7 @@ class CythonRecipe(PythonRecipe):
         with current_directory(self.get_build_dir(arch.arch)):
             hostpython = sh.Command(self.ctx.hostpython)
             shprint(hostpython, '-c', 'import sys; print(sys.path)', _env=env)
-            print('cwd is', realpath(curdir))
+            debug('cwd is {}'.format(realpath(curdir)))
             info('Trying first build of {} to get cython files: this is '
                  'expected to fail'.format(self.name))
 
@@ -1008,18 +1002,12 @@ class CythonRecipe(PythonRecipe):
             build_dir = self.get_build_dir(arch.arch)
         with current_directory(build_dir):
             info('Stripping object files')
-            if self.ctx.python_recipe.name == 'python2legacy':
-                info('Stripping object files')
-                build_lib = glob.glob('./build/lib*')
-                shprint(sh.find, build_lib[0], '-name', '*.o', '-exec',
-                        env['STRIP'], '{}', ';', _env=env)
-            else:
-                shprint(sh.find, '.', '-iname', '*.so', '-exec',
-                        '/usr/bin/echo', '{}', ';', _env=env)
-                shprint(sh.find, '.', '-iname', '*.so', '-exec',
-                        env['STRIP'].split(' ')[0], '--strip-unneeded',
-                        # '/usr/bin/strip', '--strip-unneeded',
-                        '{}', ';', _env=env)
+            shprint(sh.find, '.', '-iname', '*.so', '-exec',
+                    '/usr/bin/echo', '{}', ';', _env=env)
+            shprint(sh.find, '.', '-iname', '*.so', '-exec',
+                    env['STRIP'].split(' ')[0], '--strip-unneeded',
+                    # '/usr/bin/strip', '--strip-unneeded',
+                    '{}', ';', _env=env)
 
     def cythonize_file(self, env, build_dir, filename):
         short_filename = filename
@@ -1057,10 +1045,7 @@ class CythonRecipe(PythonRecipe):
             env['LDFLAGS'] = (env['LDFLAGS'] +
                               ' -L{}'.format(join(self.ctx.bootstrap.build_dir, 'libs', arch.arch)))
 
-        if self.ctx.python_recipe.name == 'python2legacy':
-            env['LDSHARED'] = join(self.ctx.root_dir, 'tools', 'liblink.sh')
-        else:
-            env['LDSHARED'] = env['CC'] + ' -shared'
+        env['LDSHARED'] = env['CC'] + ' -shared'
         # shprint(sh.whereis, env['LDSHARED'], _env=env)
         env['LIBLINK'] = 'NOTNONE'
         env['NDKPLATFORM'] = self.ctx.ndk_platform
