@@ -6,11 +6,11 @@ import glob
 
 
 class KivyRecipe(CythonRecipe):
-    version = '1.10.1'
+    version = '1.11.0'
     url = 'https://github.com/kivy/kivy/archive/{version}.zip'
     name = 'kivy'
 
-    depends = [('sdl2', 'pygame'), 'pyjnius']
+    depends = ['sdl2', 'pyjnius']
 
     def cythonize_build(self, env, build_dir='.'):
         super(KivyRecipe, self).cythonize_build(env, build_dir=build_dir)
