@@ -1,7 +1,5 @@
-from pythonforandroid.toolchain import Recipe, shprint, current_directory, ArchARM
+from pythonforandroid.toolchain import Recipe, current_directory, shprint
 from os.path import exists, join, realpath
-from os import uname
-import glob
 import sh
 
 
@@ -28,4 +26,5 @@ class LibShineRecipe(Recipe):
             shprint(sh.make, '-j4', _env=env)
             shprint(sh.make, 'install', _env=env)
 
+
 recipe = LibShineRecipe()
