@@ -59,8 +59,9 @@ class OpenSSLRecipe(Recipe):
 
     @property
     def use_legacy(self):
-        return any([i for i in ('python2legacy', 'python3crystax') if
-                    i in self.ctx.recipe_build_order])
+        if not self.ctx.recipe_build_order:
+            return False
+        return 'python3crystax' in self.ctx.recipe_build_order
 
     @property
     def version(self):
