@@ -6,7 +6,7 @@ class PyethereumRecipe(PythonRecipe):
     url = 'https://github.com/ethereum/pyethereum/archive/{version}.tar.gz'
 
     depends = [
-        'python2', 'setuptools', 'pycryptodome', 'pysha3', 'ethash', 'scrypt'
+        'setuptools', 'pycryptodome', 'pysha3', 'ethash', 'scrypt'
     ]
 
     call_hostpython_via_targetpython = False
