@@ -4,8 +4,8 @@ from pythonforandroid.recipe import CythonRecipe
 class PyProjRecipe(CythonRecipe):
     version = '1.9.5.1'
     url = 'https://github.com/jswhit/pyproj/archive/master.zip'
-    depends = ['python2', 'setuptools']
+    depends = ['setuptools']
     call_hostpython_via_targetpython = False
 
-    
+
 recipe = PyProjRecipe()
