@@ -1,3 +1,4 @@
+import sh
 from pythonforandroid.python import GuestPythonRecipe
 from pythonforandroid.recipe import Recipe
 
@@ -23,14 +24,17 @@ class Python3Recipe(GuestPythonRecipe):
 
     patches = ["patches/fix-ctypes-util-find-library.patch"]
 
-    depends = ['hostpython3']
-    conflicts = ['python3crystax', 'python2', 'python2legacy']
+    if sh.which('lld') is not None:
+        patches = patches + ["patches/remove-fix-cortex-a8.patch"]
+
+    depends = ['hostpython3', 'sqlite3', 'openssl', 'libffi']
+    conflicts = ['python3crystax', 'python2']
 
     configure_args = (
         '--host={android_host}',
         '--build={android_build}',
         '--enable-shared',
-        '--disable-ipv6',
+        '--enable-ipv6',
         'ac_cv_file__dev_ptmx=yes',
         'ac_cv_file__dev_ptc=no',
         '--without-ensurepip',
